==> haskell-graphviz-2999.19.0.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-graphviz.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: graphviz
version: 2999.19.0.0
id: graphviz-2999.19.0.0-ITUPoJhzVpw9pImb3jjGCU
key: graphviz-2999.19.0.0-ITUPoJhzVpw9pImb3jjGCU
license: BSD3
copyright: Matthew Sackman, Ivan Lazar Miljenovic
maintainer: Ivan.Miljenovic@gmail.com
stability: Beta
homepage: http://projects.haskell.org/graphviz/
synopsis: Bindings to Graphviz for graph visualisation.
description:
    This library provides bindings for the Dot language used by the
    Graphviz (<http://graphviz.org/>) suite of programs for visualising
    graphs, as well as functions to call those programs.
    .
    Main features of the graphviz library include:
    .
    * Almost complete coverage of all Graphviz attributes and syntax.
    .
    * Support for specifying clusters.
    .
    * The ability to use a custom node type.
    .
    * Functions for running a Graphviz layout tool with all specified
    output types.
    .
    * The ability to not only generate but also parse Dot code with two
    options: strict and liberal (in terms of ordering of statements).
    .
    * Functions to convert FGL graphs and other graph-like data structures
    to Dot code - including support to group them into clusters - with a
    high degree of customisation by specifying which attributes to use
    and limited support for the inverse operation.
    .
    * Round-trip support for passing an FGL graph through Graphviz to
    augment node and edge labels with positional information, etc.
category: Graphs, Graphics
author: Matthew Sackman, Ivan Lazar Miljenovic
exposed: True
indefinite: False
exposed-modules:
    Data.GraphViz Data.GraphViz.Algorithms Data.GraphViz.Attributes
    Data.GraphViz.Attributes.Colors
    Data.GraphViz.Attributes.Colors.Brewer
    Data.GraphViz.Attributes.Colors.SVG
    Data.GraphViz.Attributes.Colors.X11
    Data.GraphViz.Attributes.Complete Data.GraphViz.Attributes.HTML
    Data.GraphViz.Attributes.Internal Data.GraphViz.Commands
    Data.GraphViz.Commands.IO Data.GraphViz.Exception
    Data.GraphViz.Internal.State Data.GraphViz.Internal.Util
    Data.GraphViz.Parsing Data.GraphViz.PreProcessing
    Data.GraphViz.Printing Data.GraphViz.Types
    Data.GraphViz.Types.Canonical Data.GraphViz.Types.Generalised
    Data.GraphViz.Types.Graph Data.GraphViz.Types.Internal.Common
    Data.GraphViz.Types.Monadic
hidden-modules: Data.GraphViz.Algorithms.Clustering
                Data.GraphViz.Attributes.Arrows
                Data.GraphViz.Attributes.ColorScheme Data.GraphViz.Attributes.Same
                Data.GraphViz.Attributes.Values Data.GraphViz.Commands.Available
                Data.GraphViz.Types.State
abi: 41e6443834a7eedd0bfeccc3e91208ec
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/graphviz-2999.19.0.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/graphviz-2999.19.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/graphviz-2999.19.0.0
hs-libraries: HSgraphviz-2999.19.0.0-ITUPoJhzVpw9pImb3jjGCU
depends:
    base-4.10.0.0 containers-0.5.10.2 process-1.6.1.0 directory-1.3.0.2
    temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo
    fgl-5.5.3.1-Go8ZD44EYMd55DxvoKMfS6 filepath-1.4.1.2
    polyparse-1.12-4cjrjVV9T2CBEJ6qvS0lIS bytestring-0.10.8.2
    colour-2.3.3-4GTcWhusU4z5FdC5GspM4b transformers-0.5.2.0
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    wl-pprint-text-1.1.1.0-33EmaaHwePJ2aRbzjCvW04
    dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo=b2bbe16ff4ee22883b159097e4afbbd0
             fgl-5.5.3.1-Go8ZD44EYMd55DxvoKMfS6=ac7538dd2cc5ba9d74d8d090be00b377
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             polyparse-1.12-4cjrjVV9T2CBEJ6qvS0lIS=7ffa3fcddbc6dcf67e1c58e3119f38fe
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             colour-2.3.3-4GTcWhusU4z5FdC5GspM4b=cf36c1b6f2aa814cbe9c4fb4c35cd187
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             wl-pprint-text-1.1.1.0-33EmaaHwePJ2aRbzjCvW04=698e29cee9ed3f1214be2c133da94718
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=39b750082c56951484aa28fb24175e9c
haddock-interfaces: /usr/share/doc/haskell-graphviz/html/graphviz.haddock
haddock-html: /usr/share/doc/haskell-graphviz/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-graphviz-2999.19.0.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-graphviz.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: graphviz
version: 2999.19.0.0
id: graphviz-2999.19.0.0-HGkg8iBfLhBIYU4ZsAivKD
key: graphviz-2999.19.0.0-HGkg8iBfLhBIYU4ZsAivKD
license: BSD3
copyright: Matthew Sackman, Ivan Lazar Miljenovic
maintainer: Ivan.Miljenovic@gmail.com
stability: Beta
homepage: http://projects.haskell.org/graphviz/
synopsis: Bindings to Graphviz for graph visualisation.
description:
    This library provides bindings for the Dot language used by the
    Graphviz (<http://graphviz.org/>) suite of programs for visualising
    graphs, as well as functions to call those programs.
    .
    Main features of the graphviz library include:
    .
    * Almost complete coverage of all Graphviz attributes and syntax.
    .
    * Support for specifying clusters.
    .
    * The ability to use a custom node type.
    .
    * Functions for running a Graphviz layout tool with all specified
    output types.
    .
    * The ability to not only generate but also parse Dot code with two
    options: strict and liberal (in terms of ordering of statements).
    .
    * Functions to convert FGL graphs and other graph-like data structures
    to Dot code - including support to group them into clusters - with a
    high degree of customisation by specifying which attributes to use
    and limited support for the inverse operation.
    .
    * Round-trip support for passing an FGL graph through Graphviz to
    augment node and edge labels with positional information, etc.
category: Graphs, Graphics
author: Matthew Sackman, Ivan Lazar Miljenovic
exposed: True
indefinite: False
exposed-modules:
    Data.GraphViz Data.GraphViz.Algorithms Data.GraphViz.Attributes
    Data.GraphViz.Attributes.Colors
    Data.GraphViz.Attributes.Colors.Brewer
    Data.GraphViz.Attributes.Colors.SVG
    Data.GraphViz.Attributes.Colors.X11
    Data.GraphViz.Attributes.Complete Data.GraphViz.Attributes.HTML
    Data.GraphViz.Attributes.Internal Data.GraphViz.Commands
    Data.GraphViz.Commands.IO Data.GraphViz.Exception
    Data.GraphViz.Internal.State Data.GraphViz.Internal.Util
    Data.GraphViz.Parsing Data.GraphViz.PreProcessing
    Data.GraphViz.Printing Data.GraphViz.Types
    Data.GraphViz.Types.Canonical Data.GraphViz.Types.Generalised
    Data.GraphViz.Types.Graph Data.GraphViz.Types.Internal.Common
    Data.GraphViz.Types.Monadic
hidden-modules: Data.GraphViz.Algorithms.Clustering
                Data.GraphViz.Attributes.Arrows
                Data.GraphViz.Attributes.ColorScheme Data.GraphViz.Attributes.Same
                Data.GraphViz.Attributes.Values Data.GraphViz.Commands.Available
                Data.GraphViz.Types.State
abi: 32fa7c2e90273b4ec94eaf6bb870d13d
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/graphviz-2999.19.0.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/graphviz-2999.19.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/graphviz-2999.19.0.0
hs-libraries: HSgraphviz-2999.19.0.0-HGkg8iBfLhBIYU4ZsAivKD
depends:
    base-4.10.0.0 containers-0.5.10.2 process-1.6.1.0 directory-1.3.0.2
    temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo
    fgl-5.5.4.0-COv1pCfgmI26gh5vvUifJw filepath-1.4.1.2
    polyparse-1.12-4cjrjVV9T2CBEJ6qvS0lIS bytestring-0.10.8.2
    colour-2.3.3-4GTcWhusU4z5FdC5GspM4b transformers-0.5.2.0
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    wl-pprint-text-1.1.1.0-33EmaaHwePJ2aRbzjCvW04
    dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo=b2bbe16ff4ee22883b159097e4afbbd0
             fgl-5.5.4.0-COv1pCfgmI26gh5vvUifJw=96db640363318340f6e2e30376562558
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             polyparse-1.12-4cjrjVV9T2CBEJ6qvS0lIS=7ffa3fcddbc6dcf67e1c58e3119f38fe
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             colour-2.3.3-4GTcWhusU4z5FdC5GspM4b=cf36c1b6f2aa814cbe9c4fb4c35cd187
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             wl-pprint-text-1.1.1.0-33EmaaHwePJ2aRbzjCvW04=698e29cee9ed3f1214be2c133da94718
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=39b750082c56951484aa28fb24175e9c
haddock-interfaces: /usr/share/doc/haskell-graphviz/html/graphviz.haddock
haddock-html: /usr/share/doc/haskell-graphviz/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
